@@ -94,6 +94,17 @@ NEW_OUTPUT = True
 SEPERATOR = "::"
 
 
+def is_balanced(s: str) -> bool:
+    """
+    Check if a string has balanced parentheses
+    """
+    if s.count("(") != s.count(")"):
+        return False
+    if s.count("{") != s.count("}"):
+        return False
+    return True
+
+
 class RSTReader:
     verbose = False
     gather_docs = False  # used only during Development
@@ -132,6 +143,27 @@ class RSTReader:
             self.last_line = ""
         return self.last_line
 
+    def extend_and_balance_line(self) -> str:
+        """
+        Append the current line + next line in order to try to balance the parentheses
+        in order to do this the rst_test array is changed by the function
+        and max_line is adjusted
+        """
+        append = 0
+        newline = self.rst_text[self.line_no]
+        while not is_balanced(newline) and self.line_no >= 0 and (self.line_no + append + 1) <= self.max_line:
+            append += 1
+            # concat the lines
+            newline += self.rst_text[self.line_no + append]
+        # only update line if things balanced out correctly
+        if is_balanced(newline):
+            self.rst_text[self.line_no] = newline
+            for i in range(append):
+                self.rst_text.pop(self.line_no + 1)
+                self.max_line -= 1
+        # reprocess line
+        return self.line
+
     @property
     def module_names(self) -> List[str]:
         "list of possible module names [uname , name] (longest first)"
@@ -170,7 +202,7 @@ class RSTReader:
 
     def read_file(self, filename: Path):
         log.debug(f"Reading : {filename}")
-        # ingore Unicode decoding issues
+        # ignore Unicode decoding issues
         with open(filename, errors="ignore", encoding="utf8") as file:
             self.rst_text = file.readlines()
 
@@ -520,6 +552,8 @@ class RSTReader:
         ## py:staticmethod  - py:classmethod - py:decorator
         # ref: https://sphinx-tutorial.readthedocs.io/cheatsheet/
         log.debug(f"# {self.line.rstrip()}")
+        if not is_balanced(self.line):
+            self.extend_and_balance_line()
 
         ## rst_hint is used to access the method decorator ( method, staticmethod, staticmethod ... )
         rst_hint = self.get_rst_hint()
